@@ -1,28 +1,14 @@
-# -*- coding: utf-8 -*-
 """Configuration introspection and defaults."""
-from __future__ import absolute_import, unicode_literals
-
-import sys
 from collections import deque, namedtuple
 from datetime import timedelta
 
-from celery.five import items, keys, python_2_unicode_compatible
 from celery.utils.functional import memoize
 from celery.utils.serialization import strtobool
 
 __all__ = ('Option', 'NAMESPACES', 'flatten', 'find')
 
-is_jython = sys.platform.startswith('java')
-is_pypy = hasattr(sys, 'pypy_version_info')
 
 DEFAULT_POOL = 'prefork'
-if is_jython:
-    DEFAULT_POOL = 'solo'
-elif is_pypy:
-    if sys.pypy_version_info[0:3] < (1, 5, 0):
-        DEFAULT_POOL = 'solo'
-    else:
-        DEFAULT_POOL = 'prefork'
 
 DEFAULT_ACCEPT_CONTENT = ['json']
 DEFAULT_PROCESS_LOG_FMT = """
@@ -43,18 +29,17 @@ searchresult = namedtuple('searchresult', ('namespace', 'key', 'type'))
 
 def Namespace(__old__=None, **options):
     if __old__ is not None:
-        for key, opt in items(options):
+        for key, opt in options.items():
             if not opt.old:
                 opt.old = {o.format(key) for o in __old__}
     return options
 
 
 def old_ns(ns):
-    return {'{0}_{{0}}'.format(ns)}
+    return {f'{ns}_{{0}}'}
 
 
-@python_2_unicode_compatible
-class Option(object):
+class Option:
     """Describes a Celery configuration option."""
 
     alt = None
@@ -67,15 +52,15 @@ class Option(object):
     def __init__(self, default=None, *args, **kwargs):
         self.default = default
         self.type = kwargs.get('type') or 'string'
-        for attr, value in items(kwargs):
+        for attr, value in kwargs.items():
             setattr(self, attr, value)
 
     def to_python(self, value):
         return self.typemap[self.type](value)
 
     def __repr__(self):
-        return '<Option: type->{0} default->{1!r}>'.format(self.type,
-                                                           self.default)
+        return '<Option: type->{} default->{!r}>'.format(self.type,
+                                                         self.default)
 
 
 NAMESPACES = Namespace(
@@ -231,11 +216,6 @@ NAMESPACES = Namespace(
         timeout=Option(type='float'),
         save_meta_as_text=Option(True, type='bool'),
     ),
-    riak=Namespace(
-        __old__=old_ns('celery_riak'),
-
-        backend_settings=Option(type='dict'),
-    ),
     security=Namespace(
         __old__=old_ns('celery_security'),
 
@@ -364,12 +344,11 @@ def flatten(d, root='', keyfilter=_flatten_keys):
     stack = deque([(root, d)])
     while stack:
         ns, options = stack.popleft()
-        for key, opt in items(options):
+        for key, opt in options.items():
             if isinstance(opt, dict):
                 stack.append((ns + key + '_', opt))
             else:
-                for ret in keyfilter(ns, key, opt):
-                    yield ret
+                yield from keyfilter(ns, key, opt)
 
 
 DEFAULTS = {
@@ -381,18 +360,18 @@ _TO_OLD_KEY = {new_key: old_key for old_key, new_key, _ in __compat}
 _TO_NEW_KEY = {old_key: new_key for old_key, new_key, _ in __compat}
 __compat = None
 
-SETTING_KEYS = set(keys(DEFAULTS))
-_OLD_SETTING_KEYS = set(keys(_TO_NEW_KEY))
+SETTING_KEYS = set(DEFAULTS.keys())
+_OLD_SETTING_KEYS = set(_TO_NEW_KEY.keys())
 
 
 def find_deprecated_settings(source):  # pragma: no cover
     from celery.utils import deprecated
     for name, opt in flatten(NAMESPACES):
         if (opt.deprecate_by or opt.remove_by) and getattr(source, name, None):
-            deprecated.warn(description='The {0!r} setting'.format(name),
+            deprecated.warn(description=f'The {name!r} setting',
                             deprecation=opt.deprecate_by,
                             removal=opt.remove_by,
-                            alternative='Use the {0.alt} instead'.format(opt))
+                            alternative=f'Use the {opt.alt} instead')
     return source
 
 
@@ -407,7 +386,7 @@ def find(name, namespace='celery'):
         )
     except KeyError:
         # - Try all the other namespaces.
-        for ns, opts in items(NAMESPACES):
+        for ns, opts in NAMESPACES.items():
             if ns.lower() == name.lower():
                 return searchresult(None, ns, opts)
             elif isinstance(opts, dict):
